## neptune_aws 0.0.0

### Breaking changes
- First ([#2](https://github.com/neptune-ai/neptune-aws/pull/1))

### Features
- First ([#2](https://github.com/neptune-ai/neptune-aws/pull/1))

### Fixes
- First ([#2](https://github.com/neptune-ai/neptune-aws/pull/1))
